# pylinalg

[![CI](https://github.com/pygfx/pylinalg/actions/workflows/ci.yml/badge.svg)](https://github.com/pygfx/pylinalg/actions/workflows/ci.yml)
[![Documentation Status
](https://readthedocs.org/projects/pylinalg/badge/?version=latest)
](https://pylinalg.readthedocs.io/en/latest/?badge=latest)
[![PyPI version ](https://badge.fury.io/py/pylinalg.svg)
](https://badge.fury.io/py/pylinalg)

Linear algebra utilities for Python.

<p align="center">
[<a href="https://pylinalg.readthedocs.io/en/latest/reference.html">API Reference</a>]
</p>

## Installation

```bash
pip install pylinalg
```

### Development Install
To get a working dev install of pylinalg you can use the following steps:

```bash
# Click the Fork button on GitHub and navigate to your fork
git clone <address_of_your_fork>
cd pylinalg
# if you use a venv, create and activate it
pip install -e ".[dev,docs,examples]"
pytest tests
```
